# Changelog

## [0.2.2a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.2a1) (2024-09-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.1...0.2.2a1)

**Merged pull requests:**

- fix:versions [\#44](https://github.com/OpenVoiceOS/ovos-PHAL/pull/44) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
